tool_getparam: accept variable expansion on file names too

Reported-by: PBudmark on github
Fixes #12048
Closes #12055
diff --git a/src/tool_getparam.c b/src/tool_getparam.c
index cd9ce7b..d9772a3 100644
--- a/src/tool_getparam.c
+++ b/src/tool_getparam.c
@@ -826,8 +826,9 @@
       struct curlx_dynbuf nbuf;
       bool replaced;
 
-      if(aliases[hit].desc != ARG_STRING) {
-        /* --expand on an option that isn't a string */
+      if((aliases[hit].desc != ARG_STRING) &&
+         (aliases[hit].desc != ARG_FILENAME)) {
+        /* --expand on an option that isn't a string or a filename */
         err = PARAM_EXPAND_ERROR;
         goto error;
       }